==> alg-alg-1.37.9-sources.jar: cn/com/duiba/nezha/alg/alg/vo/dpa/CandidateActivityDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.dpa;

import java.util.ArrayList;
import java.util.List;

public class CandidateActivityDo {
    /**
     * 活动ID
     */
    private Long activityId;
    /**
     *活动召回分
     */
    private Double activityMatchScore;
    /**
     * 活动皮肤ID
     */
    private Long skinId;
    /**
     * 标题ID
     */
    private Long titleId;
    /**
     * 主标题召回分
     */
    private Double titleMatchScore;
    /**
     * 副标题ID
     */
    private Long subTitleId;
    /**
     * 副标题召回分
     */
    private Double subTitleMatchScore;
    /**
     * 奖品组合
     */
    private List<PrizeDo> prizeGroup = new ArrayList<>();

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getSkinId() {
        return skinId;
    }

    public void setSkinId(Long skinId) {
        this.skinId = skinId;
    }

    public Long getTitleId() {
        return titleId;
    }

    public void setTitleId(Long titleId) {
        this.titleId = titleId;
    }

    public Long getSubTitleId() {
        return subTitleId;
    }

    public void setSubTitleId(Long subTitleId) {
        this.subTitleId = subTitleId;
    }

    public List<PrizeDo> getPrizeGroup() {
        return prizeGroup;
    }

    public void setPrizeGroup(List<PrizeDo> prizeGroup) {
        this.prizeGroup = prizeGroup;
    }

    public Double getActivityMatchScore() {
        return activityMatchScore;
    }

    public void setActivityMatchScore(Double activityMatchScore) {
        this.activityMatchScore = activityMatchScore;
    }

    public Double getTitleMatchScore() {
        return titleMatchScore;
    }

    public void setTitleMatchScore(Double titleMatchScore) {
        this.titleMatchScore = titleMatchScore;
    }

    public Double getSubTitleMatchScore() {
        return subTitleMatchScore;
    }

    public void setSubTitleMatchScore(Double subTitleMatchScore) {
        this.subTitleMatchScore = subTitleMatchScore;
    }
}

==> alg-alg-5.0.1-20200705.034913-8-sources.jar: cn/com/duiba/nezha/alg/alg/vo/dpa/CandidateActivityDo.java <==
package cn.com.duiba.nezha.alg.alg.vo.dpa;

import java.util.ArrayList;
import java.util.List;

public class CandidateActivityDo {
    /**
     * 活动ID
     */
    private Long activityId;
    /**
     *活动召回分
     */
    private Double activityMatchScore;
    /**
     * 活动皮肤ID
     */
    private Long skinId;
    /**
     * 标题ID
     */
    private Long titleId;
    /**
     *标题标签ID，一对多，逗号分隔
     */
    private String titleTagId;
    /**
     * 主标题召回分
     */
    private Double titleMatchScore;
    /**
     * 副标题ID
     */
    private Long subTitleId;
    /**
     * 副标题标签ID，一对多，逗号分隔
     */
    private String subTitleTagId;
    /**
     * 副标题召回分
     */
    private Double subTitleMatchScore;
    /**
     * 奖品组合
     */
    private List<PrizeDo> prizeGroup = new ArrayList<>();

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Double getActivityMatchScore() {
        return activityMatchScore;
    }

    public void setActivityMatchScore(Double activityMatchScore) {
        this.activityMatchScore = activityMatchScore;
    }

    public Long getSkinId() {
        return skinId;
    }

    public void setSkinId(Long skinId) {
        this.skinId = skinId;
    }

    public Long getTitleId() {
        return titleId;
    }

    public void setTitleId(Long titleId) {
        this.titleId = titleId;
    }

    public String getTitleTagId() {
        return titleTagId;
    }

    public void setTitleTagId(String titleTagId) {
        this.titleTagId = titleTagId;
    }

    public Double getTitleMatchScore() {
        return titleMatchScore;
    }

    public void setTitleMatchScore(Double titleMatchScore) {
        this.titleMatchScore = titleMatchScore;
    }

    public Long getSubTitleId() {
        return subTitleId;
    }

    public void setSubTitleId(Long subTitleId) {
        this.subTitleId = subTitleId;
    }

    public String getSubTitleTagId() {
        return subTitleTagId;
    }

    public void setSubTitleTagId(String subTitleTagId) {
        this.subTitleTagId = subTitleTagId;
    }

    public Double getSubTitleMatchScore() {
        return subTitleMatchScore;
    }

    public void setSubTitleMatchScore(Double subTitleMatchScore) {
        this.subTitleMatchScore = subTitleMatchScore;
    }

    public List<PrizeDo> getPrizeGroup() {
        return prizeGroup;
    }

    public void setPrizeGroup(List<PrizeDo> prizeGroup) {
        this.prizeGroup = prizeGroup;
    }
}
